@@ -27,11 +27,11 @@ RDF::LinkedData::ProviderRole - Role providing important functionality for Linke
 
 =head1 VERSION
 
-Version 0.14
+Version 0.16
 
 =cut
 
-our $VERSION = '0.14';
+our $VERSION = '0.16';
 
 
 =head1 SYNOPSIS
@@ -88,8 +88,16 @@ sub BUILD {
 	my $self = shift;
 
         unless($self->model) {
-            my $store	= RDF::Trine::Store->new_with_config( $self->store );
-            $self->model(RDF::Trine::Model->new( $store ));
+	  # First, set the base if none is configured
+	  my $i = 0;
+	  foreach my $source (@{$self->store->{sources}}) {
+	    unless ($source->{base_uri}) {
+	      ${$self->store->{sources}}[$i]->{base_uri} = $self->base;
+	    }
+	    $i++;
+	  }
+	  my $store	= RDF::Trine::Store->new_with_config( $self->store );
+	  $self->model(RDF::Trine::Model->new( $store ));
 	}
 
         throw Error -text => "No valid RDF::Trine::Model, need either a store config hashref or a model." unless ($self->model);
@@ -275,6 +283,7 @@ sub response {
                 # Then, we have a foaf:page set that we should redirect to
                 $response->status(301);
                 $response->headers->header('Location' => $page);
+                $response->headers->header('Access-Control-Allow-Origin' => '*');
                 return $response;
             }
 
@@ -310,6 +319,7 @@ sub response {
             $response->headers->header('Location' => $newurl);
             $response->headers->header('Vary' => join(", ", qw(Accept)));
         }
+	$response->headers->header('Access-Control-Allow-Origin' => '*');
         return $response;
     } else {
         $response->status(404);
@@ -368,7 +378,7 @@ L<http://lists.perlrdf.org/listinfo/dev>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Gregory Todd Williams and ABC Startsiden AS.
+Copyright 2010 Kjetil Kjernsmo, Gregory Todd Williams and ABC Startsiden AS.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
